@@ -4,9 +4,6 @@
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
-// -*- mode: js2; indent-tabs-mode: nil; js2-basic-offset: 4 -*-
-// Start apps on custom workspaces
-
 import Shell from 'gi://Shell';
 
 import {Extension} from 'resource:///org/gnome/shell/extensions/extension.js';
@@ -22,7 +19,8 @@ class WindowMover {
         this._appSystem.connectObject('installed-changed',
             () => this._updateAppData(), this);
 
-        this._settings.connect('changed', this._updateAppConfigs.bind(this));
+        this._settings.connectObject('changed',
+            this._updateAppConfigs.bind(this), this);
         this._updateAppConfigs();
     }
 
@@ -58,11 +56,8 @@ class WindowMover {
 
     destroy() {
         this._appSystem.disconnectObject(this);
-
-        if (this._settings) {
-            this._settings.run_dispose();
-            this._settings = null;
-        }
+        this._settings.disconnectObject(this);
+        this._settings = null;
 
         this._appConfigs.clear();
         this._updateAppData();
