@@ -5,9 +5,6 @@
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
-// -*- mode: js2; indent-tabs-mode: nil; js2-basic-offset: 4 -*-
-// Load shell theme from ~/.local/share/themes/name/gnome-shell
-
 import Gio from 'gi://Gio';
 
 import {Extension} from 'resource:///org/gnome/shell/extensions/extension.js';
@@ -21,12 +18,13 @@ const SETTINGS_KEY = 'name';
 export default class ThemeManager extends Extension {
     enable() {
         this._settings = this.getSettings();
-        this._settings.connect(`changed::${SETTINGS_KEY}`, this._changeTheme.bind(this));
+        this._settings.connectObject(`changed::${SETTINGS_KEY}`,
+            this._changeTheme.bind(this), this);
         this._changeTheme();
     }
 
     disable() {
-        this._settings?.run_dispose();
+        this._settings?.disconnectObject();
         this._settings = null;
 
         Main.setThemeStylesheet(null);
