@@ -20,6 +20,9 @@ import * as DND from 'resource:///org/gnome/shell/ui/dnd.js';
 import * as Main from 'resource:///org/gnome/shell/ui/main.js';
 import * as PopupMenu from 'resource:///org/gnome/shell/ui/popupMenu.js';
 import {DashItemContainer} from 'resource:///org/gnome/shell/ui/dash.js';
+import {
+    ANIMATION_TIME as SLIDE_ANIMATION_TIME,
+} from 'resource:///org/gnome/shell/ui/overview.js';
 
 import {WorkspaceIndicator} from './workspaceIndicator.js';
 
@@ -85,10 +88,10 @@ class WindowContextMenu extends PopupMenu.PopupMenu {
 
         this._maximizeItem = new PopupMenu.PopupMenuItem('');
         this._maximizeItem.connect('activate', () => {
-            if (this._metaWindow.get_maximized() === Meta.MaximizeFlags.BOTH)
-                this._metaWindow.unmaximize(Meta.MaximizeFlags.BOTH);
+            if (this._metaWindow.is_maximized())
+                this._metaWindow.unmaximize();
             else
-                this._metaWindow.maximize(Meta.MaximizeFlags.BOTH);
+                this._metaWindow.maximize();
         });
         this.addMenuItem(this._maximizeItem);
 
@@ -123,9 +126,7 @@ class WindowContextMenu extends PopupMenu.PopupMenu {
     }
 
     _updateMaximizeItem() {
-        let maximized = this._metaWindow.maximized_vertically &&
-                        this._metaWindow.maximized_horizontally;
-        this._maximizeItem.label.text = maximized
+        this._maximizeItem.label.text = this._metaWindow.is_maximized()
             ? _('Unmaximize') : _('Maximize');
     }
 }
@@ -432,12 +433,10 @@ class BaseButton extends DashItemContainer {
         return this._button.has_style_class_name('focused');
     }
 
-    // eslint-disable-next-line camelcase
     get ignore_workspace() {
         return this._ignoreWorkspace;
     }
 
-    // eslint-disable-next-line camelcase
     set ignore_workspace(ignore) {
         if (this._ignoreWorkspace === ignore)
             return;
@@ -733,7 +732,7 @@ class AppContextMenu extends PopupMenu.PopupMenu {
         this._maximizeItem = new PopupMenu.PopupMenuItem(_('Maximize all'));
         this._maximizeItem.connect('activate', () => {
             this._appButton.getWindowList().forEach(w => {
-                w.maximize(Meta.MaximizeFlags.BOTH);
+                w.maximize();
             });
         });
         this.addMenuItem(this._maximizeItem);
@@ -741,7 +740,7 @@ class AppContextMenu extends PopupMenu.PopupMenu {
         this._unmaximizeItem = new PopupMenu.PopupMenuItem(_('Unmaximize all'));
         this._unmaximizeItem.connect('activate', () => {
             this._appButton.getWindowList().forEach(w => {
-                w.unmaximize(Meta.MaximizeFlags.BOTH);
+                w.unmaximize();
             });
         });
         this.addMenuItem(this._unmaximizeItem);
@@ -760,10 +759,10 @@ class AppContextMenu extends PopupMenu.PopupMenu {
         this._minimizeItem.visible = windows.some(w => !w.minimized);
         this._unminimizeItem.visible = windows.some(w => w.minimized);
         this._maximizeItem.visible = windows.some(w => {
-            return w.get_maximized() !== Meta.MaximizeFlags.BOTH;
+            return !w.is_maximized();
         });
         this._unmaximizeItem.visible = windows.some(w => {
-            return w.get_maximized() === Meta.MaximizeFlags.BOTH;
+            return w.is_maximized();
         });
 
         super.open(animate);
@@ -983,14 +982,25 @@ class WindowList extends St.Widget {
             () => this._onWorkspaceMenuSet(), this);
         this._onWorkspaceMenuSet();
 
-        const chromeOptions = {
+        const inOverview = Main.overview.visible ||
+            (Main.layoutManager._startingUp && Main.sessionMode.hasOverview);
+
+        const overviewChromeOptions = {
             affectsStruts: true,
+        };
+        const chromeOptions = {
+            ...overviewChromeOptions,
             trackFullscreen: true,
         };
-        Main.layoutManager.addChrome(this, chromeOptions);
+        Main.layoutManager.addChrome(this, inOverview
+            ? overviewChromeOptions
+            : chromeOptions);
+
         Main.uiGroup.set_child_above_sibling(this, Main.layoutManager.panelBox);
         Main.ctrlAltTabManager.addGroup(this, _('Window List'), 'start-here-symbolic');
 
+        this.visible = !inOverview;
+
         this.width = this._monitor.width;
         this.connect('notify::height', this._updatePosition.bind(this));
         this._updatePosition();
@@ -1000,7 +1010,7 @@ class WindowList extends St.Widget {
             this._onAppStateChanged.bind(this), this);
 
         // Hack: OSK gesture is tied to visibility, piggy-back on that
-        Main.keyboard._bottomDragAction.connectObject('notify::enabled',
+        Main.keyboard._bottomDragGesture.connectObject('notify::enabled',
             action => {
                 const visible = !action.enabled;
                 if (visible) {
@@ -1024,20 +1034,20 @@ class WindowList extends St.Widget {
 
         Main.overview.connectObject(
             'showing', () => {
-                Main.layoutManager.untrackChrome(this);
-                this.hide();
+                this._retrackChrome(overviewChromeOptions);
+                this._slideOut();
                 this._updateKeyboardAnchor();
             },
+            'hiding', () => {
+                if (!this._monitor.inFullscreen)
+                    this._slideIn();
+            },
             'hidden', () => {
-                Main.layoutManager.trackChrome(this, chromeOptions);
-                this.visible = !this._monitor.inFullscreen;
+                this._retrackChrome(chromeOptions);
                 this._updateKeyboardAnchor();
             }, this);
 
         global.display.connectObject('in-fullscreen-changed', () => {
-            // Work-around for initial change from unknown to !fullscreen
-            if (Main.overview.visible)
-                this.hide();
             this._updateKeyboardAnchor();
         }, this);
 
@@ -1075,6 +1085,13 @@ class WindowList extends St.Widget {
         this._groupingModeChanged();
     }
 
+    get_transformed_position() {
+        // HACK: Remove translation we use for animations
+        //       to keep struts stable
+        const [x, y] = super.get_transformed_position();
+        return [x, y - this.translation_y];
+    }
+
     _onScrollEvent(actor, event) {
         let direction = event.get_scroll_direction();
         let diff = 0;
@@ -1103,6 +1120,29 @@ class WindowList extends St.Widget {
             this._monitor.y + this._monitor.height - this.height);
     }
 
+    _retrackChrome(options) {
+        Main.layoutManager.untrackChrome(this);
+        Main.layoutManager.trackChrome(this, options);
+    }
+
+    _slideIn() {
+        this.show();
+        this.ease({
+            translation_y: 0,
+            duration: SLIDE_ANIMATION_TIME,
+            mode: Clutter.AnimationMode.EASE_OUT_QUAD,
+        });
+    }
+
+    _slideOut() {
+        this.ease({
+            translation_y: this.height,
+            duration: SLIDE_ANIMATION_TIME,
+            mode: Clutter.AnimationMode.EASE_OUT_QUAD,
+            onComplete: () => this.hide(),
+        });
+    }
+
     _updateWorkspaceIndicatorVisibility() {
         let workspaceManager = global.workspace_manager;
         let hasWorkspaces = this._mutterSettings.get_boolean('dynamic-workspaces') ||
@@ -1463,12 +1503,6 @@ class BottomWorkspaceIndicator extends WorkspaceIndicator {
         GObject.registerClass(this);
     }
 
-    constructor(params) {
-        super(params);
-
-        this.remove_style_class_name('panel-button');
-    }
-
     setMenu(menu) {
         super.setMenu(menu);
 
